Module net — Inmanta 2017.3dev documentation

# Module net

> - License: Apache 2.0
> - Version: 0.5.0
> - Author: Inmanta <code@inmanta.com>
> - Upstream project: https://github.com/inmanta/net.git

## Typedefs

typedef `net::mac_addr`
  - Base type `string`
  - Type constraint `(self regex re.compile('^([0-9a-fA-F]{2})(:[0-9a-fA-F]{2}){5}|$'))`

typedef `net::vlan_id`
  - Base type `number`
  - Type constraint `((self >= 0) and (self < 4096))`

## Entities

entity `net::Interface`

  Parents: `std::Entity`

  This interface models an ethernet network interface.

  attribute net::mac_addr `mac`=''
  attribute string `name`
  attribute bool `vlan`=False
  attribute number `mtu`=1500
  relation std::Host `host` [1]

    other end: `std::Host.ifaces [0:*]`

  The following implements statements select implementations for this entity:

  > - `std::none`